import React from "react"
import { getProfile, isAdministrator } from "../../../services/auth"
import { FormattedMessage } from "react-intl"
import { Card, Descriptions, Empty } from "antd"

const Account = () => {
	const user = getProfile()
	if (user) {
		return (
			<Card>
				<Descriptions
					title={<FormattedMessage id="user.info" />}
					bordered
					column={{ xxl: 3, xl: 3, lg: 2, md: 2, sm: 1, xs: 1 }}
				>
					<Descriptions.Item label={<FormattedMessage id="user.email" />}>
						{user.email}
					</Descriptions.Item>
					{user.user_metadata.full_name ? (
						<Descriptions.Item label={<FormattedMessage id="user.name" />}>
							{user.user_metadata.full_name}
						</Descriptions.Item>
					) : null}
					<Descriptions.Item label={<FormattedMessage id="user.role" />}>
						{isAdministrator() ? "Administrator" : "User"}
					</Descriptions.Item>
					{user.app_metadata.provider ? (
						<Descriptions.Item label={<FormattedMessage id="user.provider" />}>
							{user.app_metadata.provider}
						</Descriptions.Item>
					) : null}
					<Descriptions.Item label={<FormattedMessage id="user.created_at" />}>
						{user.created_at}
					</Descriptions.Item>
				</Descriptions>
			</Card>
		)
	}

	return (
		<Card>
			<Empty />
		</Card>
	)
}

export default Account
