import GoTrue from "gotrue-js"
import { navigate } from "gatsby"
import { notification } from "antd"

const isBrowser = typeof window !== "undefined"
const gotrue = new GoTrue({
	APIUrl: `https://${process.env.GATSBY_NETLIFY_SITE_DOMAIN}/.netlify/identity`,
	audience: "",
	setCookie: true,
})

export const isAuthenticated = () => {
	if (!isBrowser) {
		return false
	}

	const user = gotrue.currentUser()
	if (user && user.email) {
		return true
	}

	return false
}
export const getProfile = () => {
	if (!isBrowser) {
		return null
	}

	const user = gotrue.currentUser()
	return user
}
export const isAdministrator = () => {
	if (!isBrowser) {
		return false
	}

	const user = gotrue.currentUser()
	if (
		user.app_metadata.roles &&
		user.app_metadata.roles.indexOf("Administrator") > -1
	) {
		return true
	}

	return false
}
export const logout = () => {
	const user = gotrue.currentUser()
	user
		.logout()
		.then(() => {
			if (isBrowser) {
				navigate("/")
			} else {
				console.log("Can not logout in undefined window!")
				notification["error"]({
					message: "Error",
					description: "Can not logout in undefined window!",
					duration: 0,
				})
			}
		})
		.catch((error) => {
			let message = ""
			let description = ""
			if (error.json) {
				console.log("error json ", error.json)
				message = error.json.error || error.name
				description = error.json.error_description || error.json.msg
			} else if (error.stack) {
				console.log("error stack ", error.stack)
				message = error.name
				description = error.stack
			} else if (error.data) {
				console.log("error data ", error.data)
				message = error.name
				description = error.message
			} else {
				console.log("error ", error)
				message = `Unknow Error`
				description = ``
			}
			notification["error"]({
				message: message,
				description: description,
				duration: 0,
			})
		})
}

export const fetchLogin = (email, password, remember) => {
	const cango = gotrue
		.login(email, password, remember)
		.then(() => {
			return true
		})
		.catch((error) => {
			let message = ""
			let description = ""
			if (error.json) {
				console.log("error json ", error.json)
				message = error.json.error || error.name
				description = error.json.error_description || error.json.msg
			} else if (error.stack) {
				console.log("error stack ", error.stack)
				message = error.name
				description = error.stack
			} else if (error.data) {
				console.log("error data ", error.data)
				message = error.name
				description = error.message
			} else {
				console.log("error ", error)
				message = `Unknow Error`
				description = ``
			}
			notification["error"]({
				message: message,
				description: description,
				duration: 0,
			})
			return false
		})
	return cango
}

export const fetchSignUp = (email, password) => {
	const cango = gotrue
		.signup(email, password)
		.then(() => {
			return true
		})
		.catch((error) => {
			let message = ""
			let description = ""
			if (error.json) {
				console.log("error json ", error.json)
				message = error.json.error || error.name
				description = error.json.error_description || error.json.msg
			} else if (error.stack) {
				console.log("error stack ", error.stack)
				message = error.name
				description = error.stack
			} else if (error.data) {
				console.log("error data ", error.data)
				message = error.name
				description = error.message
			} else {
				console.log("error ", error)
				message = `Unknow Error`
				description = ``
			}
			notification["error"]({
				message: message,
				description: description,
				duration: 0,
			})
			return false
		})
	return cango
}

export default gotrue
